function bootstrap_stats = regression_bootstrap_short(X, block_length, nboot)

        X            = X(~any(isnan(X()),2),:);
        N            = size(X,1);                                 % The number of observations
        Z            = size(X,2);                                 % The number of variables (dependent and independent)
        num_blocks   = ceil(N/block_length);                      % The number of blocks needed
        
        missing_obs  = num_blocks*block_length - N;               % Number of missing observations in order to have an integer number of blocks
        data_add     = floor(rand(missing_obs,nboot)*N)+1;        % Draw randomly to fill in missing observations
    
        Indices      = 1:num_blocks*block_length';                % All of the indices from 1 to N
        Indices      = reshape(Indices,block_length,num_blocks);  % This reshapes the indices so that each column represents 1 block, or x months of data.  The 22nd column, for example, tells which data are in block  22.
        
        for i = 1:nboot                                            
            
            randblock       = unidrnd(num_blocks,1,num_blocks);   % Choose which blocks to use
            Ind_sim         = Indices(:,randblock);               % Find which data are in each block
            Ind_sim         = Ind_sim(:);                         % Stack these blocks into one big sample
            X_temp          = [X ; X(data_add(:,i),:)];           % Add randomly chosen data to have the right number of blocks
            X_sim           = X_temp(Ind_sim,:);                  % Construct the simulated data
            
            [b,~,~,~,stats] = regress(X_sim(:,1), X_sim(:,2:end));
            
            slope(:,i) = b;
            R_sq(:,i)  = stats(1,1);
           
        end;  
        
      for k = 1:Z-1    
        
       bootstrap_stats(k,:)     = [mean(slope(k,:)), std(slope(k,:)), prctile(slope(k,:), 5), prctile(slope(k,:), 95), prctile(slope(k,:), 2.5), prctile(slope(k,:), 97.5), prctile(slope(k,:), 0.5), prctile(slope(k,:), 99.5)];
       
      end
            
      