function ResultsBoot = BlockBootstrap(data,nboot)

% =====================
% BLOCK BOOTSTRAP
% =====================
block_length = 3; % number of observations in each block of the bootstrap

% Block bootstrap
ResultsBoot  = NaN*zeros(nboot,1);
                
N            = length(data);
num_blocks   = ceil(N/block_length);                      %   The number of blocks needed
missing_obs  = num_blocks*block_length - N;               %   Number of missing observations in order to have an integer number of blocks
data_add     = floor(rand(missing_obs,nboot)*N)+1;        %   Draw randomly to fill in missing observations
    
Indices      = 1:num_blocks*block_length';                % All of the indices from 1 to N
Indices      = reshape(Indices,block_length,num_blocks);  % This reshapes the indices so that each column represent 1 block, or x  months of data.  The 22nd column, for example, tells which data are in block  22


for i=1:nboot                                             % Number of bootstrap samples
    
    randblock       = unidrnd(num_blocks,1,num_blocks);   % Choose which blocks to use
    Ind_sim         = Indices(:,randblock);               % Find which data are in each block
    Ind_sim         = Ind_sim(:);                         % Stack these block into one big sample
    data_temp       = [data ; data(data_add(:,i),:)];     % Add randomly chosen data to have the right number of blocks
    Xsim            = data_temp(Ind_sim,:);               % Construct the simulated data
    
    ResultsBoot(i,1)= nanmean(Xsim);

end;
