function [Portfolios_Var1,Portfolios_Var2,Portfolios_Var3,Portfolios_Var4,Portfolios_VarSort,Track_portfolios] = Build_portfolios_for4variables(Var1,Var2,Var3,Var4,VarSort,sorting_variable,Number_portfolios)


[T,N] = size(Var1);


%==========================================
% Sort on interest rates (nominal or real)
%==========================================

switch sorting_variable
    case 1 
        [X_sorted,Index_sorting]= sort(VarSort,2);   %#ok<ASGLU> % Using nominal interest rates
    case 2
        [X_sorted,Index_sorting]= sort(repmat(nanmean(VarSort),T,1),2);   %#ok<ASGLU> % Using unconditional averages of nominal interest rates
end;


Var1_sorted          =  zeros(T,N);
Var2_sorted          =  zeros(T,N);
Var3_sorted          =  zeros(T,N);
Var4_sorted          =  zeros(T,N);
VarSort_sorted       =  zeros(T,N);
Track_countries      =  zeros(T,N);

for t=1:T                        % For each date
    for s=1:N                    % For each country
       Var1_sorted(t,s)        =  Var1(t,Index_sorting(t,s));
       Var2_sorted(t,s)        =  Var2(t,Index_sorting(t,s));
       Var3_sorted(t,s)        =  Var3(t,Index_sorting(t,s));
       Var4_sorted(t,s)        =  Var4(t,Index_sorting(t,s));
       VarSort_sorted(t,s)     =  VarSort(t,Index_sorting(t,s));
       Track_countries(t,s)    =  Index_sorting(t,s);
    end;
end;


%\\\\\\\\\\\\\\\\\\\\\\\\\\\\\
% Count the numbers of countries available at every date
%\\\\\\\\\\\\\\\\\\\\\\\\\\\\\
Count_Returns     = zeros(size(Var1_sorted,1),1);
for t=1:size(Var1_sorted,1)                                               % For each date
    for c=1:size(Var1_sorted,2)                                           % For each country
        Count_Returns(t,1) =          Count_Returns(t,1)+(not(isnan(Var1_sorted(t,c))));
    end;
end;

%==========================================
% Build portfolios
%==========================================
Portfolios_Var1      =  zeros(T,Number_portfolios);
Portfolios_Var2      =  zeros(T,Number_portfolios);
Portfolios_Var3      =  zeros(T,Number_portfolios);
Portfolios_Var4      =  zeros(T,Number_portfolios);
Portfolios_VarSort   =  zeros(T,Number_portfolios);
Count_group          =  zeros(T,Number_portfolios);
trades               =  zeros(T,Number_portfolios);
Track_portfolios     =  zeros(T,Number_portfolios);

for t=1:T                   % For each date        
    for n=1:Number_portfolios;                  % For each portfolio
        if n==Number_portfolios;                % Special case: last portfolio
            for m=1+(n-1)*floor(Count_Returns(t,1)*(1/Number_portfolios)):n*floor(Count_Returns(t,1)*(1/Number_portfolios))+rem(Count_Returns(t,1),Number_portfolios);                 
                
                Portfolios_Var1(t,n)                        =   Portfolios_Var1(t,n)+Var1_sorted(t,m);
                Portfolios_Var2(t,n)                        =   Portfolios_Var2(t,n)+Var2_sorted(t,m);
                Portfolios_Var3(t,n)                        =   Portfolios_Var3(t,n)+Var3_sorted(t,m);
                Portfolios_Var4(t,n)                        =   Portfolios_Var4(t,n)+Var4_sorted(t,m);
                Portfolios_VarSort(t,n)                     =   Portfolios_VarSort(t,n)+VarSort_sorted(t,m);
                Count_group(t,n)                          =   Count_group(t,n)+1;
                Track_portfolios(t,Track_countries(t,m))  =   n;

                % Test if the country changes portfolio
                if  t>1 && Track_portfolios(t-1,Track_countries(t,m)) ~=n
                    trades(t,n)=trades(t,n)+1;
                end;                 
            end;
        else                                    % All portfolios except the last one
            for m=1+(n-1)*floor(Count_Returns(t)*(1/Number_portfolios)):n*floor(Count_Returns(t)*(1/Number_portfolios));
                
                Portfolios_Var1(t,n)                        =   Portfolios_Var1(t,n)+Var1_sorted(t,m);
                Portfolios_Var2(t,n)                        =   Portfolios_Var2(t,n)+Var2_sorted(t,m);
                Portfolios_Var3(t,n)                        =   Portfolios_Var3(t,n)+Var3_sorted(t,m);
                Portfolios_Var4(t,n)                        =   Portfolios_Var4(t,n)+Var4_sorted(t,m);
                Portfolios_VarSort(t,n)                     =   Portfolios_VarSort(t,n)+VarSort_sorted(t,m);
                Count_group(t,n)                          =   Count_group(t,n)+1;
                Track_portfolios(t,Track_countries(t,m))  =   n;

                % Test if the country changes portfolio
                if  t>1 && Track_portfolios(t-1,Track_countries(t,m)) ~=n
                    trades(t,n)=trades(t,n)+1;
                end;
            end;
        end;
        if Count_group(t,n)>0;
           Portfolios_Var1(t,n)                    =   Portfolios_Var1(t,n)/Count_group(t,n);  
           Portfolios_Var2(t,n)                    =   Portfolios_Var2(t,n)/Count_group(t,n);  
           Portfolios_Var3(t,n)                    =   Portfolios_Var3(t,n)/Count_group(t,n);  
           Portfolios_Var4(t,n)                    =   Portfolios_Var4(t,n)/Count_group(t,n);  
           Portfolios_VarSort(t,n)                 =   Portfolios_VarSort(t,n)/Count_group(t,n);  

        else
           Portfolios_Var1(t,n)                    =   NaN;  
           Portfolios_Var2(t,n)                    =   NaN;  
           Portfolios_Var3(t,n)                    =   NaN;  
           Portfolios_Var4(t,n)                    =   NaN;  
           Portfolios_VarSort(t,n)                 =   NaN;  
        end;       
    end;
end;

