clear 
close all
restoredefaultpath
addpath(genpath('jsz_library'))
clc

% Load some data for the US: mats (1*J) and yields (T*J) (to match time period)
load('sample_zeros.mat') 

% load ZC data for G10 countries
load('ZC_Spliced_Model_M_2016.mat','ZC_Spliced_Model_M');% Maturities are 3, 6, 9, ..., 120 or 180 months (ie up to 15 years max)
ZC_Sample = ZC_Spliced_Model_M;
Countries_Sample = {'Australia';'Canada';'Germany';'Japan';'New Zealand';'Norway';'Sweden';'Switzerland';'United Kingdom';'United States'}; 
Nc = size(Countries_Sample,1);

M = 200*12;  % maximum maturity (in months) to consider; M+1 is infinite maturity

starting_date = datenum(1985,4,30);
ending_date   = datenum(2015,12,31);
NM            = months(starting_date,ending_date)+1;

ZC_all  = NaN*zeros(NM,1+7,Nc); % 8 yields if 15yr
HRP_all = NaN*zeros(NM,M+2,Nc);
yield_3m = NaN*zeros(NM,1+1,Nc);

load(strcat('dates_foreign_10_2016.mat'),'dates_foreign'); % use US to retrieve dates
dates = dates_foreign;

selection = [1;2;3;4;6;8;9;10]; % Australia, Canada, Germany, Japan, Norway, Switzerland, United Kingdom, United States

for m=1:size(selection,1)
    n = selection(m);
    
    ZC_all(:,1,n)  = dates;
    HRP_all(:,1,n) = dates;
    yield_3m(:,1,n) = dates;
    
    load(strcat('log_3m_return_model_',int2str(n),'_2016.mat'),'log_3m_return_model');
    load(strcat('yields_model_selected_',int2str(n),'_2016.mat'),'yields_model_selected');
    load(strcat('dates_foreign_',int2str(n),'_2016.mat'),'dates_foreign');

    line_start = find(ZC_all(:,1,n)==dates_foreign(1,1));
    line_end   = find(ZC_all(:,1,n)==dates_foreign(end,1));
    line_start_y3m = find(ZC_Sample(:,1,n)==dates_foreign(1,1));
    line_end_y3m   = find(ZC_Sample(:,1,n)==dates_foreign(end,1));
    ZC_all(line_start:line_end,2:end,n)  = yields_model_selected;
    HRP_all(line_start:line_end,2:end,n) = log_3m_return_model;
    yield_3m(line_start:line_end,2,n)    = ZC_Sample(line_start_y3m: line_end_y3m,2,n);
   
end

sorting_variable    = 1; 
Number_portfolios   = 2;


HPR_nom_10 = NaN*zeros(size(HRP_all,1),Nc-1);
for n=1:Nc
    HPR_nom_10(:,n) = HRP_all(:,121,n)-HRP_all(:,4,n);       % excess return: 10-year maturity return minus 3-month maturity return
end

HPR_nom_long = NaN*zeros(size(HRP_all,1),Nc-1);
for n=1:Nc
    HPR_nom_long(:,n) = HRP_all(:,end,n)-HRP_all(:,4,n);     % excess return: infinite maturity return minus 3-month maturity return
end

HPR_nom_diff = HPR_nom_long - HPR_nom_10;                    % difference between infinite-maturity return and 10-year return


%----------------------
% Country-level results
%----------------------

nanmax(HPR_nom_long);
nanmin(HPR_nom_long);
nanmean(HPR_nom_long);
nanstd(HPR_nom_long);

IR3M_nom = NaN*zeros(size(ZC_all,1),Nc-1);   
IR6M_nom = NaN*zeros(size(ZC_all,1),Nc-1);   
for n=1:Nc
    IR3M_nom(:,n) = yield_3m(:,2,n);                 % level: 3-month yield
    IR6M_nom(:,n) = ZC_all(:,2,n);
end

IR3M_nom_lag = [NaN*zeros(3,Nc); IR3M_nom(1:end-3,:)];

Slope_nom = NaN*zeros(size(ZC_all,1),Nc-1);  
for n=1:Nc
    Slope_nom(:,n) = ZC_all(:,end,n)-yield_3m(:,2,n); % slope: 10-year yield - 3-month yield
end

Slope_nom_lag = [NaN*zeros(3,Nc); Slope_nom(1:end-3,:)];

nboot        = 10000; % number of blocks
ResultsBoot_HPR_nom_10   = NaN*zeros(nboot,size(HPR_nom_10,2));
ResultsBoot_HPR_nom_long = NaN*zeros(nboot,size(HPR_nom_long,2));
ResultsBoot_HPR_nom_diff = NaN*zeros(nboot,size(HPR_nom_diff,2));

for i=1: size(HPR_nom_10,2)
    ResultsBoot_HPR_nom_10(:,i)   = BlockBootstrap(400*HPR_nom_10(:,i),nboot);
    ResultsBoot_HPR_nom_long(:,i) = BlockBootstrap(400*HPR_nom_long(:,i),nboot);
    ResultsBoot_HPR_nom_diff(:,i) = BlockBootstrap(400*HPR_nom_diff(:,i),nboot);
end;

for i=1: size(HPR_nom_10,2)
    Corr_HPR_nom(1,i) = corr(HPR_nom_10(:,i),HPR_nom_long(:,i),'rows','complete');
end;

Table_Results_1 = [nanmean(HPR_nom_10)*400; nanstd(ResultsBoot_HPR_nom_10); nanmean(HPR_nom_long)*400; nanstd(ResultsBoot_HPR_nom_long); Corr_HPR_nom; nanmean(HPR_nom_diff)*400; nanstd(ResultsBoot_HPR_nom_diff);];
Table_Results_1 = Table_Results_1(:,[10 1 2 3 4 6 8 9]);

disp('----------------------------------------------'); 
disp('Individual Country Results (1985-2015 sample)');
disp('----------------------------------------------'); 
latex(Table_Results_1,'%-4.2f');

%----------------------
% Portfolios: Sorting on levels
%----------------------
% function [Portfolios_ERba,Portfolios_ER,Portfolios_Q,Portfolios_TBdifnom] 
%= Build_portfolios_generic(ER_nom,ER_nom_long,ER_nom_short,Q_ch_nom,TBdif_nom,sorting_variable,Number_portfolios)


% [Portfolios_HPR_nom_10,~,~,Portfolios_IR3M_nom] = ...
%     Build_portfolios_generic(HPR_nom_10(:,1:Nc-1),HPR_nom_10(:,1:Nc-1),HPR_nom_10(:,1:Nc-1),HPR_nom_10(:,1:Nc-1),IR3M_nom_lag(:,1:Nc-1),sorting_variable,Number_portfolios); % do not include the US

[Portfolios_HPR_nom_10,~,~,Portfolios_IR3M_nom] = ...
    Build_portfolios_generic(HPR_nom_10,HPR_nom_10,HPR_nom_10,HPR_nom_10,IR3M_nom_lag,sorting_variable,Number_portfolios); % include the US


nanmean(Portfolios_IR3M_nom)*100;

nanmean(Portfolios_HPR_nom_10)*400;


% [Portfolios_HPR_nom_long,~,~,Portfolios_IR3M_nom] = ...
%     Build_portfolios_generic(HPR_nom_long(:,1:Nc-1),HPR_nom_long(:,1:Nc-1),HPR_nom_long(:,1:Nc-1),HPR_nom_long(:,1:Nc-1),IR3M_nom_lag(:,1:Nc-1),sorting_variable,Number_portfolios); % do not include the US

[Portfolios_HPR_nom_long,~,~,Portfolios_IR3M_nom] = ...
    Build_portfolios_generic(HPR_nom_long,HPR_nom_long,HPR_nom_long,HPR_nom_long,IR3M_nom_lag,sorting_variable,Number_portfolios); % include the US


nanmean(Portfolios_HPR_nom_long)*400;
nanstd(Portfolios_HPR_nom_long*400)/sqrt(size(Portfolios_HPR_nom_long,1));

% [Portfolios_HPR_nom_diff,~,~,Portfolios_IR3M_nom] = ...
%     Build_portfolios_generic(HPR_nom_diff(:,1:Nc-1),HPR_nom_diff(:,1:Nc-1),HPR_nom_diff(:,1:Nc-1),HPR_nom_diff(:,1:Nc-1),IR3M_nom_lag(:,1:Nc-1),sorting_variable,Number_portfolios); % do not include the US

[Portfolios_HPR_nom_diff,~,~,Portfolios_IR3M_nom] = ...
    Build_portfolios_generic(HPR_nom_diff,HPR_nom_diff,HPR_nom_diff,HPR_nom_diff,IR3M_nom_lag,sorting_variable,Number_portfolios); % include the US

nanmean(Portfolios_HPR_nom_diff)*400;
nanstd(Portfolios_HPR_nom_diff*400)/sqrt(size(Portfolios_HPR_nom_diff,1));

ResultsBoot_Portfolios_HPR_nom_10 = NaN*zeros(nboot,size(Portfolios_HPR_nom_10,2));
ResultsBoot_Portfolios_HPR_nom_long = NaN*zeros(nboot,size(Portfolios_HPR_nom_long,2));
ResultsBoot_Portfolios_HPR_nom_diff = NaN*zeros(nboot,size(Portfolios_HPR_nom_diff,2));

for i=1: size(Portfolios_HPR_nom_10,2)
    ResultsBoot_Portfolios_HPR_nom_10(:,i) = BlockBootstrap(400*Portfolios_HPR_nom_10(:,i),nboot);
    ResultsBoot_Portfolios_HPR_nom_long(:,i) = BlockBootstrap(400*Portfolios_HPR_nom_long(:,i),nboot);
    ResultsBoot_Portfolios_HPR_nom_diff(:,i) = BlockBootstrap(400*Portfolios_HPR_nom_diff(:,i),nboot);
end;

for i=1: size(Portfolios_HPR_nom_10,2)
    Corr_Portfolios_HPR_nom(1,i) = corr(Portfolios_HPR_nom_10(:,i),Portfolios_HPR_nom_long(:,i),'rows','complete');
end;

% Build table results:

Table_Results_2 = [nanmean(Portfolios_IR3M_nom)*100; nanmean(Portfolios_HPR_nom_10)*400; nanstd(ResultsBoot_Portfolios_HPR_nom_10);...
    nanmean(Portfolios_HPR_nom_long)*400; nanstd(ResultsBoot_Portfolios_HPR_nom_long);Corr_Portfolios_HPR_nom;nanmean(Portfolios_HPR_nom_diff)*400; nanstd(ResultsBoot_Portfolios_HPR_nom_diff)];

disp('----------------------------------------------'); 
disp('IR-Sorted Portfolio Results');
disp('----------------------------------------------'); 
latex(Table_Results_2,'%-4.2f');
    
%----------------------
% Portfolios: Sorting on slopes
%----------------------

% [Portfolios_HPR_nom_10,~,~,Portfolios_Slope_nom] = ...
%     Build_portfolios_generic(HPR_nom_10(:,1:Nc-1),HPR_nom_10(:,1:Nc-1),HPR_nom_10(:,1:Nc-1),HPR_nom_10(:,1:Nc-1),Slope_nom_lag(:,1:Nc-1),sorting_variable,Number_portfolios); % do not include the US

[Portfolios_HPR_nom_10,~,~,Portfolios_Slope_nom] = ...
    Build_portfolios_generic(HPR_nom_10,HPR_nom_10,HPR_nom_10,HPR_nom_10,Slope_nom_lag,sorting_variable,Number_portfolios); % include the US

nanmean(Portfolios_Slope_nom)*100;

nanmean(Portfolios_HPR_nom_10)*400;

% [Portfolios_HPR_nom_long,~,~,Portfolios_Slope_nom] = ...
%     Build_portfolios_generic(HPR_nom_long(:,1:Nc-1),HPR_nom_long(:,1:Nc-1),HPR_nom_long(:,1:Nc-1),HPR_nom_long(:,1:Nc-1),Slope_nom_lag(:,1:Nc-1),sorting_variable,Number_portfolios); % do not include the US

[Portfolios_HPR_nom_long,~,~,Portfolios_Slope_nom] = ...
    Build_portfolios_generic(HPR_nom_long,HPR_nom_long,HPR_nom_long,HPR_nom_long,Slope_nom_lag,sorting_variable,Number_portfolios); % include the US

nanmean(Portfolios_HPR_nom_long)*400;
nanstd(Portfolios_HPR_nom_long*400)/sqrt(size(Portfolios_HPR_nom_long,1));

% [Portfolios_HPR_nom_diff,~,~,Portfolios_Slope_nom] = ...
%     Build_portfolios_generic(HPR_nom_diff(:,1:Nc-1),HPR_nom_diff(:,1:Nc-1),HPR_nom_diff(:,1:Nc-1),HPR_nom_diff(:,1:Nc-1),Slope_nom_lag(:,1:Nc-1),sorting_variable,Number_portfolios); % do not include the US

[Portfolios_HPR_nom_diff,~,~,Portfolios_Slope_nom] = ...
    Build_portfolios_generic(HPR_nom_diff,HPR_nom_diff,HPR_nom_diff,HPR_nom_diff,Slope_nom_lag,sorting_variable,Number_portfolios); % include the US

nanmean(Portfolios_HPR_nom_diff)*400;
nanstd(Portfolios_HPR_nom_diff*400)/sqrt(size(Portfolios_HPR_nom_diff,1));

ResultsBoot_Portfolios_HPR_nom_10 = NaN*zeros(nboot,size(Portfolios_HPR_nom_10,2));
ResultsBoot_Portfolios_HPR_nom_long = NaN*zeros(nboot,size(Portfolios_HPR_nom_long,2));
ResultsBoot_Portfolios_HPR_nom_diff = NaN*zeros(nboot,size(Portfolios_HPR_nom_diff,2));

for i=1: size(Portfolios_HPR_nom_10,2)
    ResultsBoot_Portfolios_HPR_nom_10(:,i) = BlockBootstrap(400*Portfolios_HPR_nom_10(:,i),nboot);
    ResultsBoot_Portfolios_HPR_nom_long(:,i) = BlockBootstrap(400*Portfolios_HPR_nom_long(:,i),nboot);
    ResultsBoot_Portfolios_HPR_nom_diff(:,i) = BlockBootstrap(400*Portfolios_HPR_nom_diff(:,i),nboot);
end;

for i=1: size(Portfolios_HPR_nom_10,2)
    Corr_Portfolios_HPR_nom(1,i) = corr(Portfolios_HPR_nom_10(:,i),Portfolios_HPR_nom_long(:,i),'rows','complete');
end;

% Build table results:
Table_Results_3 = [nanmean(Portfolios_Slope_nom)*100; nanmean(Portfolios_HPR_nom_10)*400; nanstd(ResultsBoot_Portfolios_HPR_nom_10);...
    nanmean(Portfolios_HPR_nom_long)*400; nanstd(ResultsBoot_Portfolios_HPR_nom_long);Corr_Portfolios_HPR_nom;nanmean(Portfolios_HPR_nom_diff)*400; nanstd(ResultsBoot_Portfolios_HPR_nom_diff)];

disp('----------------------------------------------'); 
disp('Slope-Sorted Portfolio Results');
disp('----------------------------------------------');     
latex(Table_Results_3,'%-4.2f');