clear 
close all
restoredefaultpath
addpath(genpath('jsz_library'))
clc

% This gives a sample estimation of an N-factor "without error" GDTSM.
% See "A New Perspective on Gaussian Dynamic Term Structure Models" by Joslin, Singleton and Zhu

% Load some data: mats (1*J) and yields (T*J)
load('sample_zeros.mat') 
% For the US, maturities are  0.5    1.0    2.0    3.0    5.0    7.0   10

load('ZC_Spliced_M.mat','ZC_Spliced_M');% Maturities are 3, 6, 9, ..., 120 or 180 months (ie up to 15 years max)
ZC_Sample = ZC_Spliced_M;
Countries_Sample = {'Australia';'Canada';'Germany'; 'Japan';'New Zealand';'Norway';'Sweden';'Switzerland';'United Kingdom';'United States'}; 
Nc = size(Countries_Sample,1);

ZC_UK = ZC_Sample(:,:,end-1);
% Replace US yields with UK yields
ZC_UK_selection = [ZC_UK(:,2) ZC_UK(:,1+4) ZC_UK(:,1+2*4) ZC_UK(:,1+3*4) ZC_UK(:,1+5*4) ZC_UK(:,1+7*4) ZC_UK(:,1+10*4)];

% Same time window
line_start = find(ZC_UK(:,1) == dates(1,1));
line_end = find(ZC_UK(:,1) == dates(end,1));
yields_UK = ZC_UK_selection(line_start:line_end,:);

% replace US yields by UK yields
yields = yields_UK;

% Setup format of model/data:
N = 2;
W = pcacov(cov(yields));
W = W(:,1:N)';  % N*J
cP = yields*W'; % T*N
dt = 1/12;

% Estimate the model by ML. 
help sample_estimation_fun
VERBOSE = true;
[llks, AcP, BcP, AX, BX, kinfQ, K0P_cP, K1P_cP, sigma_e, K0Q_cP, K1Q_cP, rho0_cP, rho1_cP, cP, llkP, llkQ,  K0Q_X, K1Q_X, rho0_X, rho1_X] = ...
        sample_estimation_fun(W, yields, mats, dt, VERBOSE);


break;

% Check definition of variables by reproducing yields
yt = ones(size(cP,1),1)*AcP + cP*BcP;


% Extend to longer maturities
maturities = [1,2,3,5,7,10];

Sigma_cP   = cov(cP);
% H0d        = Sigma_cP;
WBXp       = W*BX.'; % N*N
Sigma_X    = (W*BX')\Sigma_cP/(BX*W');

K0d        = K0Q_X;
K1d        = K1Q_X;
rho0d      = rho0_X;
rho1d      = rho1_X;
H0d        = Sigma_X;

[By, Ay]   = gaussianDiscreteYieldLoadingsRecurrence(maturities, K0d, K1d, H0d, rho0d, rho1d);

% yt_longmat = ones(size(cP,1),1)*Ay + cP*By;

